# papanda

Useful tools for statistical data exploration.

Version 0.0.1a1 includes tests for detecting outliers:

1) Generalized ESD Test for Outliers (GESD) for normal distribution;
2) Cochran's test for detecting outliers in a set of variances;
3) Greenwood's test for exponential distribution;
4) Modified boxplot;
5) Trimmed mean.
